#[non_exhaustive]pub struct StreamChunk {
pub text: String,
pub prompt_tokens: Option<u64>,
pub completion_tokens: Option<u64>,
pub cached_input_tokens: Option<u64>,
}Expand description
A single chunk emitted during streaming inference.
The final chunk in a stream includes token usage counts. Marked
#[non_exhaustive] because new fields may be added in future minor
releases.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.text: StringThe text fragment for this chunk.
prompt_tokens: Option<u64>Number of prompt tokens (only set on the final chunk).
completion_tokens: Option<u64>Number of completion tokens (only set on the final chunk).
cached_input_tokens: Option<u64>Number of prompt tokens that were served from the persistent KV-cache prefix (only set on the final chunk).